@@ -136,18 +136,14 @@ __imlib_RenderGetPixel(Display * d, Drawable w, Visual * v, Colormap cm,
    return 0;
 }
 
-__hidden void
-                    __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
-                                           XImage * xim, Visual * v,
-                                           Context * ct);
-
-void
+static void
 __imlib_generic_render(DATA32 * src, int jump, int w, int h, int dx, int dy,
                        XImage * xim, Visual * v, Context * ct)
 {
    unsigned int        x, y, r, g, b, val, hh;
    unsigned int        rmask, gmask, bmask;
    int                 i, rshift, gshift, bshift;
+
    const DATA8         _dither_88[8][8] = {
       {0, 32, 8, 40, 2, 34, 10, 42},
       {48, 16, 56, 24, 50, 18, 58, 26},
@@ -282,7 +278,7 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
    /* if the input rect size < 0 dont render either */
    if ((sw <= 0) || (sh <= 0))
       return;
-   /* if the output is too big (8k arbitary limit here) dont bother */
+   /* if the output is too big (8k arbitrary limit here) dont bother */
    if ((abs(dw) > X_MAX_DIM) || (abs(dh) > X_MAX_DIM))
       return;
    /* clip the source rect to be within the actual image */
@@ -307,7 +303,7 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
    /* if the input rect size < 0 dont render either */
    if ((sw <= 0) || (sh <= 0))
       return;
-   /* if the output is too big (8k arbitary limit here) dont bother */
+   /* if the output is too big (8k arbitrary limit here) dont bother */
    if ((abs(dw) > X_MAX_DIM) || (abs(dh) > X_MAX_DIM))
       return;
    /* if we are scaling the image at all make a scaling buffer */
@@ -436,7 +432,7 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
                     }
                   memcpy(buf, im->data + ((y + sy) * im->w),
                          im->w * hh * sizeof(DATA32));
-                  __imlib_DataCmodApply(buf, dw, hh, im->w - dw, NULL, cmod);
+                  __imlib_DataCmodApply(buf, im->w, hh, 0, NULL, cmod);
                   pointer = buf + sx;
                   jump = im->w - sw;
                }
@@ -479,7 +475,7 @@ __imlib_RenderImage(Display * d, ImlibImage * im,
         XFreeGC(disp, gc);
         gc = 0;
      }
-   /* if we didnt have a gc... create it */
+   /* if we didn't have a gc... create it */
    if (!gc)
      {
         disp = d;
@@ -587,8 +583,7 @@ __imlib_RenderImageSkewed(Display * d, ImlibImage * im, Drawable w, Drawable m,
    ct = __imlib_GetContext(d, v, cm, depth);
 
    back = __imlib_CreateImage(dw, dh, NULL);
-   back->data = malloc(dw * dh * sizeof(DATA32));
-   memset(back->data, 0, dw * dh * sizeof(DATA32));
+   back->data = calloc(dw * dh, sizeof(DATA32));
    __imlib_GrabDrawableToRGBA(back->data, 0, 0, dw, dh, d, w, 0, v, cm,
                               depth, dx1, dy1, dw, dh, 0, 1);
 
